@@ -23,7 +23,7 @@
 #include "ColorScheme.h"
 
 // Qt
-#include <QtGui/QPainter>
+#include <QPainter>
 
 // KDE
 #include <KConfig>
@@ -33,8 +33,7 @@
 // STL
 #include <random>
 
-namespace
-{
+namespace {
 const int FGCOLOR_INDEX = 0;
 const int BGCOLOR_INDEX = 1;
 }
@@ -80,7 +79,7 @@ const ColorEntry ColorScheme::defaultTable[TABLE_COLORS] = {
     ColorEntry(QColor(0x65, 0x65, 0x65))
 };
 
-const char* const ColorScheme::colorNames[TABLE_COLORS] = {
+const char * const ColorScheme::colorNames[TABLE_COLORS] = {
     "Foreground",
     "Background",
     "Color0",
@@ -112,7 +111,7 @@ const char* const ColorScheme::colorNames[TABLE_COLORS] = {
     "Color6Faint",
     "Color7Faint"
 };
-const char* const ColorScheme::translatedColorNames[TABLE_COLORS] = {
+const char * const ColorScheme::translatedColorNames[TABLE_COLORS] = {
     I18N_NOOP2("@item:intable palette", "Foreground"),
     I18N_NOOP2("@item:intable palette", "Background"),
     I18N_NOOP2("@item:intable palette", "Color 1"),
@@ -149,7 +148,7 @@ QString ColorScheme::colorNameForIndex(int index)
 {
     Q_ASSERT(index >= 0 && index < TABLE_COLORS);
 
-    return QString(colorNames[index]);
+    return QString(QLatin1String(colorNames[index]));
 }
 
 QString ColorScheme::translatedColorNameForIndex(int index)
@@ -159,73 +158,82 @@ QString ColorScheme::translatedColorNameForIndex(int index)
     return i18nc("@item:intable palette", translatedColorNames[index]);
 }
 
-ColorScheme::ColorScheme()
+ColorScheme::ColorScheme() :
+    _description(QString()),
+    _name(QString()),
+    _table(0),
+    _randomTable(0),
+    _opacity(1.0),
+    _wallpaper(0)
 {
-    _table = 0;
-    _randomTable = 0;
-    _opacity = 1.0;
     setWallpaper(QString());
 }
 
-ColorScheme::ColorScheme(const ColorScheme& other)
-    : _table(0)
-    , _randomTable(0)
-    , _opacity(other._opacity)
-    , _wallpaper(other._wallpaper)
+ColorScheme::ColorScheme(const ColorScheme &other) :
+    _table(0),
+    _randomTable(0),
+    _opacity(other._opacity),
+    _wallpaper(other._wallpaper)
 {
     setName(other.name());
     setDescription(other.description());
 
     if (other._table != 0) {
-        for (int i = 0 ; i < TABLE_COLORS ; i++)
+        for (int i = 0; i < TABLE_COLORS; i++) {
             setColorTableEntry(i, other._table[i]);
+        }
     }
 
     if (other._randomTable != 0) {
-        for (int i = 0 ; i < TABLE_COLORS ; i++) {
-            const RandomizationRange& range = other._randomTable[i];
+        for (int i = 0; i < TABLE_COLORS; i++) {
+            const RandomizationRange &range = other._randomTable[i];
             setRandomizationRange(i, range.hue, range.saturation, range.value);
         }
     }
 }
+
 ColorScheme::~ColorScheme()
 {
     delete[] _table;
     delete[] _randomTable;
 }
 
-void ColorScheme::setDescription(const QString& aDescription)
+void ColorScheme::setDescription(const QString &aDescription)
 {
     _description = aDescription;
 }
+
 QString ColorScheme::description() const
 {
     return _description;
 }
 
-void ColorScheme::setName(const QString& aName)
+void ColorScheme::setName(const QString &aName)
 {
     _name = aName;
 }
+
 QString ColorScheme::name() const
 {
     return _name;
 }
 
-void ColorScheme::setColorTableEntry(int index , const ColorEntry& entry)
+void ColorScheme::setColorTableEntry(int index, const ColorEntry &entry)
 {
     Q_ASSERT(index >= 0 && index < TABLE_COLORS);
 
-    if (!_table) {
+    if (_table == nullptr) {
         _table = new ColorEntry[TABLE_COLORS];
 
-        for (int i = 0; i < TABLE_COLORS; i++)
+        for (int i = 0; i < TABLE_COLORS; i++) {
             _table[i] = defaultTable[i];
+        }
     }
 
     _table[index] = entry;
 }
-ColorEntry ColorScheme::colorEntry(int index , uint randomSeed) const
+
+ColorEntry ColorScheme::colorEntry(int index, uint randomSeed) const
 {
     Q_ASSERT(index >= 0 && index < TABLE_COLORS);
 
@@ -235,8 +243,7 @@ ColorEntry ColorScheme::colorEntry(int index , uint randomSeed) const
         return entry;
     }
 
-
-    const RandomizationRange& range = _randomTable[index];
+    const RandomizationRange &range = _randomTable[index];
 
     // 32-bit Mersenne Twister
     // Can't use default_random_engine, because in GCC this maps to
@@ -244,42 +251,46 @@ ColorEntry ColorScheme::colorEntry(int index , uint randomSeed) const
     std::mt19937 randomEngine(randomSeed);
 
     int hueDifference = 0;
-    if (range.hue) {
+    if (range.hue != 0u) {
         std::uniform_int_distribution<int> dist(0, range.hue);
         hueDifference = dist(randomEngine);
     }
 
     int saturationDifference = 0;
-    if (range.saturation) {
+    if (range.saturation != 0u) {
         std::uniform_int_distribution<int> dist(0, range.saturation);
         saturationDifference = dist(randomEngine) - range.saturation / 2;
     }
 
     int valueDifference = 0;
-    if (range.value) {
+    if (range.value != 0u) {
         std::uniform_int_distribution<int> dist(0, range.value);
         valueDifference = dist(randomEngine) - range.value / 2;
     }
 
-    QColor& color = entry.color;
+    QColor &color = entry;
 
     int newHue = qAbs((color.hue() + hueDifference) % MAX_HUE);
-    int newValue = qMin(qAbs(color.value() + valueDifference) , 255);
-    int newSaturation = qMin(qAbs(color.saturation() + saturationDifference) , 255);
+    int newValue = qMin(qAbs(color.value() + valueDifference), 255);
+    int newSaturation = qMin(qAbs(color.saturation() + saturationDifference), 255);
 
     color.setHsv(newHue, newSaturation, newValue);
 
     return entry;
 }
-void ColorScheme::getColorTable(ColorEntry* table , uint randomSeed) const
+
+void ColorScheme::getColorTable(ColorEntry *table, uint randomSeed) const
 {
-    for (int i = 0 ; i < TABLE_COLORS ; i++)
+    for (int i = 0; i < TABLE_COLORS; i++) {
         table[i] = colorEntry(i, randomSeed);
+    }
 }
+
 bool ColorScheme::randomizedBackgroundColor() const
 {
     return _randomTable == 0 ? false : !_randomTable[BGCOLOR_INDEX].isNull();
 }
+
 void ColorScheme::setRandomizedBackgroundColor(bool randomize)
 {
     // the hue of the background color is allowed to be randomly
@@ -287,73 +298,79 @@ void ColorScheme::setRandomizedBackgroundColor(bool randomize)
     //
     // the value and saturation are left alone to maintain read-ability
     if (randomize) {
-        setRandomizationRange(BGCOLOR_INDEX , MAX_HUE , 255 , 0);
+        setRandomizationRange(BGCOLOR_INDEX, MAX_HUE, 255, 0);
     } else {
-        if (_randomTable)
-            setRandomizationRange(BGCOLOR_INDEX , 0 , 0 , 0);
+        if (_randomTable != nullptr) {
+            setRandomizationRange(BGCOLOR_INDEX, 0, 0, 0);
+        }
     }
 }
 
-void ColorScheme::setRandomizationRange(int index , quint16 hue , quint8 saturation ,
-                                        quint8 value)
+void ColorScheme::setRandomizationRange(int index, quint16 hue, quint8 saturation, quint8 value)
 {
     Q_ASSERT(hue <= MAX_HUE);
     Q_ASSERT(index >= 0 && index < TABLE_COLORS);
 
-    if (_randomTable == 0)
+    if (_randomTable == 0) {
         _randomTable = new RandomizationRange[TABLE_COLORS];
+    }
 
     _randomTable[index].hue = hue;
     _randomTable[index].value = value;
     _randomTable[index].saturation = saturation;
 }
 
-const ColorEntry* ColorScheme::colorTable() const
+const ColorEntry *ColorScheme::colorTable() const
 {
-    if (_table)
+    if (_table != nullptr) {
         return _table;
-    else
+    } else {
         return defaultTable;
+    }
 }
+
 QColor ColorScheme::foregroundColor() const
 {
-    return colorTable()[FGCOLOR_INDEX].color;
+    return colorTable()[FGCOLOR_INDEX];
 }
+
 QColor ColorScheme::backgroundColor() const
 {
-    return colorTable()[BGCOLOR_INDEX].color;
+    return colorTable()[BGCOLOR_INDEX];
 }
+
 bool ColorScheme::hasDarkBackground() const
 {
     // value can range from 0 - 255, with larger values indicating higher brightness.
     // so 127 is in the middle, anything less is deemed 'dark'
     return backgroundColor().value() < 127;
 }
+
 void ColorScheme::setOpacity(qreal aOpacity)
 {
     _opacity = aOpacity;
 }
+
 qreal ColorScheme::opacity() const
 {
     return _opacity;
 }
 
-void ColorScheme::read(const KConfig& config)
+void ColorScheme::read(const KConfig &config)
 {
     KConfigGroup configGroup = config.group("General");
 
-    const QString schemeDescription = configGroup.readEntry("Description", I18N_NOOP("Un-named Color Scheme"));
+    const QString schemeDescription = configGroup.readEntry("Description", i18nc("@item", "Un-named Color Scheme"));
 
     _description = i18n(schemeDescription.toUtf8().constData());
     _opacity = configGroup.readEntry("Opacity", qreal(1.0));
     setWallpaper(configGroup.readEntry("Wallpaper", QString()));
 
-    for (int i = 0 ; i < TABLE_COLORS ; i++) {
+    for (int i = 0; i < TABLE_COLORS; i++) {
         readColorEntry(config, i);
     }
 }
-
-void ColorScheme::readColorEntry(const KConfig& config , int index)
+void ColorScheme::readColorEntry(const KConfig &config, int index)
 {
     KConfigGroup configGroup = config.group(colorNameForIndex(index));
 
@@ -364,19 +381,20 @@ void ColorScheme::readColorEntry(const KConfig& config , int index)
 
     ColorEntry entry;
 
-    entry.color = configGroup.readEntry("Color", QColor());
+    entry = configGroup.readEntry("Color", QColor());
 
-    setColorTableEntry(index , entry);
+    setColorTableEntry(index, entry);
 
     const quint16 hue = static_cast<quint16>(configGroup.readEntry("MaxRandomHue", 0));
     const quint8 value = static_cast<quint8>(configGroup.readEntry("MaxRandomValue", 0));
     const quint8 saturation = static_cast<quint8>(configGroup.readEntry("MaxRandomSaturation", 0));
 
-    if (hue != 0 || value != 0 || saturation != 0)
-        setRandomizationRange(index , hue , saturation , value);
+    if (hue != 0 || value != 0 || saturation != 0) {
+        setRandomizationRange(index, hue, saturation, value);
+    }
 }
 
-void ColorScheme::write(KConfig& config) const
+void ColorScheme::write(KConfig &config) const
 {
     KConfigGroup configGroup = config.group("General");
 
@@ -384,18 +402,18 @@ void ColorScheme::write(KConfig& config) const
     configGroup.writeEntry("Opacity", _opacity);
     configGroup.writeEntry("Wallpaper", _wallpaper->path());
 
-    for (int i = 0 ; i < TABLE_COLORS ; i++) {
+    for (int i = 0; i < TABLE_COLORS; i++) {
         writeColorEntry(config, i);
     }
 }
 
-void ColorScheme::writeColorEntry(KConfig& config , int index) const
+void ColorScheme::writeColorEntry(KConfig &config, int index) const
 {
     KConfigGroup configGroup = config.group(colorNameForIndex(index));
 
-    const ColorEntry& entry = colorTable()[index];
+    const ColorEntry &entry = colorTable()[index];
 
-    configGroup.writeEntry("Color", entry.color);
+    configGroup.writeEntry("Color", entry);
 
     // Remove unused keys
     if (configGroup.hasKey("Transparent")) {
@@ -419,7 +437,7 @@ void ColorScheme::writeColorEntry(KConfig& config , int index) const
     }
 }
 
-void ColorScheme::setWallpaper(const QString& path)
+void ColorScheme::setWallpaper(const QString &path)
 {
     _wallpaper = new ColorSchemeWallpaper(path);
 }
@@ -429,9 +447,9 @@ ColorSchemeWallpaper::Ptr ColorScheme::wallpaper() const
     return _wallpaper;
 }
 
-ColorSchemeWallpaper::ColorSchemeWallpaper(const QString& aPath)
-    : _path(aPath),
-      _picture(0)
+ColorSchemeWallpaper::ColorSchemeWallpaper(const QString &aPath) :
+    _path(aPath),
+    _picture(0)
 {
 }
 
@@ -442,15 +460,18 @@ ColorSchemeWallpaper::~ColorSchemeWallpaper()
 
 void ColorSchemeWallpaper::load()
 {
-    if (_path.isEmpty())
+    if (_path.isEmpty()) {
         return;
+    }
 
     // Create and load original pixmap
-    if (!_picture)
+    if (_picture == nullptr) {
         _picture = new QPixmap();
+    }
 
-    if (_picture->isNull())
+    if (_picture->isNull()) {
         _picture->load(_path);
+    }
 }
 
 bool ColorSchemeWallpaper::isNull() const
@@ -458,10 +479,11 @@ bool ColorSchemeWallpaper::isNull() const
     return _path.isEmpty();
 }
 
-bool ColorSchemeWallpaper::draw(QPainter& painter, const QRect& rect, qreal opacity)
+bool ColorSchemeWallpaper::draw(QPainter &painter, const QRect &rect, qreal opacity)
 {
-    if (!_picture || _picture->isNull())
+    if ((_picture == nullptr) || _picture->isNull()) {
         return false;
+    }
 
     if (qFuzzyCompare(1.0, opacity)) {
         painter.drawTiledPixmap(rect, *_picture, rect.topLeft());
@@ -469,7 +491,7 @@ bool ColorSchemeWallpaper::draw(QPainter& painter, const QRect& rect, qreal opac
     }
     painter.save();
     painter.setCompositionMode(QPainter::CompositionMode_Source);
-    painter.fillRect(rect, QColor(0,0,0,0));
+    painter.fillRect(rect, QColor(0, 0, 0, 0));
     painter.setOpacity(opacity);
     painter.drawTiledPixmap(rect, *_picture, rect.topLeft());
     painter.restore();
@@ -480,4 +502,3 @@ QString ColorSchemeWallpaper::path() const
 {
     return _path;
 }
-
