@@ -22,25 +22,23 @@
 #define HISTORYSIZEDIALOG_H
 
 // KDE
-#include <KDialog>
+#include <QDialog>
 
 // Konsole
 #include "Enumeration.h"
 
-namespace Ui
-{
+namespace Ui {
 class HistorySizeDialog;
 }
 
-namespace Konsole
-{
-class HistorySizeDialog : public KDialog
+namespace Konsole {
+class HistorySizeDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    explicit HistorySizeDialog(QWidget* parent = 0);
-    ~HistorySizeDialog();
+    explicit HistorySizeDialog(QWidget *parent = 0);
+    ~HistorySizeDialog() Q_DECL_OVERRIDE;
 
     /** See HistorySizeWidget::setMode. */
     void setMode(Enum::HistoryModeEnum aMode);
@@ -55,7 +53,7 @@ public:
     int lineCount() const;
 
 private:
-    Ui::HistorySizeDialog* _ui;
+    Ui::HistorySizeDialog *_ui;
 };
 }
 
